@@ -108,7 +108,7 @@ public final class TwitterOAuthActivator extends HousekeepingActivator {
                 public boolean isEnabled(String capability, Session ses) throws OXException {
                     if ("twitter".equals(capability)) {
                         final ServerSession session = ServerSessionAdapter.valueOf(ses);
-                        if (session.isAnonymous()) {
+                        if (session.isAnonymous() || session.getUser().isGuest()) {
                             return false;
                         }
 
