@@ -250,6 +250,11 @@ public enum OAuthExceptionCodes implements DisplayableOXExceptionCode {
      */
     OAUTH_PROBLEM_ACCESS_DENIED("The OAuth provider refused to permit this Consumer to access the protected resources.", CATEGORY_PERMISSION_DENIED, 39, null),
 
+    /**
+     * The OAuth access token for the '%1$s' OAuth account with id '%2$s' of user '%3$s' in context '%4$s' is invalid. Reauthorization is required.
+     */
+    OAUTH_ACCESS_TOKEN_INVALID("The OAuth access token for the '%1$s' OAuth account with id '%2$s' of user '%3$s' in context '%4$s' is invalid. Reauthorization is required.", CATEGORY_ERROR, 40, OAuthExceptionMessages.OAUTH_TOKEN_INVALID),
+
     ;
 
     private final Category category;
