@@ -102,6 +102,9 @@ public final class OAuthExceptionMessages implements LocalizableStrings {
     // Your '%1$s' access was revoked. You have to reauthorize the server to use your account with a new password. To do so, go to Configuration -> My Social Configuration -> Accounts. Then try again.
     public static String OAUTH_PROBLEM_TOKEN_REVOKED_MSG = "Your '%1$s' access was revoked. You have to reauthorize the server to use your account with a new password. To do so, go to Configuration -> My Social Configuration -> Accounts. Then try again.";
 
+    // Your access token for '%1$s' is invalid. You have to reauthorize your account.
+    public static String OAUTH_TOKEN_INVALID = "Your access token for '%1$s' is invalid. You have to reauthorize your account.";
+
     /**
      * Initializes a new {@link OAuthExceptionMessages}.
      */
