@@ -115,6 +115,12 @@ public final class XingExceptionMessages implements LocalizableStrings {
     // A XING account has already been requested for E-Mail address %1$s.
     public static final String LEAD_ALREADY_EXISTS_MSG = "A XING account has already been requested for E-Mail address %1$s.";
 
+    // The XING app that you are using does not hold the required permissions in order to perform the requested action
+    public static final String INSUFFICIENT_PRIVILEGES_MSG = "The XING app that you are using does not hold the required permissions in order to perform the requested action";
+
+    // No XING OAuth access available for user %1$s in context %2$s.
+    public static final String NO_OAUTH_ACCOUNT_MSG = "No XING OAuth access available. Please create a XING OAuth account.";
+
     /**
      * Initializes a new {@link XingExceptionMessages}.
      */
